@@ -85,6 +85,6 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 		
 	}
 	
-attr(K2P,"unit") <- "mol/kg"
+#attr(K2P,"unit") <- "mol/kg"
 print(K2P);
 }
